# Changelog

## [0.1.1](https://github.com/open-feature/python-sdk-contrib/compare/openfeature-provider-ofrep/v0.1.0...openfeature-provider-ofrep/v0.1.1) (2025-01-21)


### 🐛 Bug Fixes

* Allow configuring ofrep provider requests to api at base … ([#142](https://github.com/open-feature/python-sdk-contrib/issues/142)) ([09402df](https://github.com/open-feature/python-sdk-contrib/commit/09402df3129c1b9d219465b82807fa53aafec039))
* Pin the ofrep provider's requests dep &gt;=2.27.0 because of… ([#161](https://github.com/open-feature/python-sdk-contrib/issues/161)) ([9ffc7ec](https://github.com/open-feature/python-sdk-contrib/commit/9ffc7ec91d1fff0d436099e878fac9c080a42b51))

## 0.1.0 (2024-10-02)


### ✨ New Features

* add initial skeleton for OFREP provider ([#86](https://github.com/open-feature/python-sdk-contrib/issues/86)) ([00a5a18](https://github.com/open-feature/python-sdk-contrib/commit/00a5a18a76ef1435de67f312e384a97823bd185b))
* implement basic functionality of OFREP provider ([#88](https://github.com/open-feature/python-sdk-contrib/issues/88)) ([cb42cc0](https://github.com/open-feature/python-sdk-contrib/commit/cb42cc0001e19793f391351a1ce5bafe1831025f))

## Changelog
